radontea
========

|PyPI Version| |Build Status| |Coverage Status|

Algorithms to compute the inverse Radon trannsform (e.g. SART, backprojection, Fourier interpolation).


Documentation
-------------
The documentation is available `here <http://RI-imaging.github.io/radontea/>`__.


Installation
------------
The package can be installed from the Python package index.

::

    pip install radontea


Usage
-----
For a general idea of use cases, execute radontea as a package
(matplotlib needs to be installed):

::

    python -m radontea


Testing
-------
Some functionalities of the module are tested with

::

    python setup.py test



.. |PyPI Version| image:: http://img.shields.io/pypi/v/radontea.svg
   :target: https://pypi.python.org/pypi/radontea
.. |Build Status| image:: http://img.shields.io/travis/RI-imaging/radontea.svg
   :target: https://travis-ci.org/RI-imaging/radontea
.. |Coverage Status| image:: https://img.shields.io/coveralls/RI-imaging/radontea.svg
   :target: https://coveralls.io/r/RI-imaging/radontea

